---
title: Default values mechanics
---

# Default values mechanics

Some keys in identifiers (e.g., `base_name`, `zone_name`, `location`, `time`) can be omitted when defaults are configured or inferable. The defaulting behavior is described in this flowchart:

![defaults](../images/default_value_selection.png)
